summary refs log tree commit diff stats
path: root/compiler/nimconf.nim
diff options
context:
space:
mode:
Diffstat (limited to 'compiler/nimconf.nim')
-rw-r--r--compiler/nimconf.nim13
1 files changed, 7 insertions, 6 deletions
diff --git a/compiler/nimconf.nim b/compiler/nimconf.nim
index 136a0d454..98fe831d3 100644
--- a/compiler/nimconf.nim
+++ b/compiler/nimconf.nim
@@ -1,6 +1,6 @@
 #
 #
 #           The Nimrod Compiler
 #        (c) Copyright 2012 Andreas Rumpf
 #
 #    See the file "copying.txt", included in this
@@ -14,7 +14,7 @@ import
   options, idents, wordrecg
 
 # ---------------- configuration file parser -----------------------------
 # we use Nimrod's scanner here to safe space and work
 
 proc ppGetTok(L: var TLexer, tok: var TToken) = 
   # simple filter
@@ -224,8 +224,8 @@ proc loadConfigs*(cfg: string) =
   if libpath == "": 
     # choose default libpath:
     var prefix = getPrefixDir()
-    if prefix == "/usr": libpath = "/usr/lib/nimrod"
-    elif prefix == "/usr/local": libpath = "/usr/local/lib/nimrod"
+    if prefix == "/usr": libpath = "/usr/lib/nim"
+    elif prefix == "/usr/local": libpath = "/usr/local/lib/nim"
     else: libpath = joinPath(prefix, "lib")
 
   if optSkipConfigFile notin gGlobalOptions:
@@ -244,5 +244,6 @@ proc loadConfigs*(cfg: string) =
     
     if gProjectName.len != 0:
       # new project wide config file:
-      readConfigFile(changeFileExt(gProjectFull, "nimrod.cfg"))
- 
+      let projectConfig = changeFileExt(gProjectFull, "nim.cfg")
+      if fileExists(projectConfig): readConfigFile(projectConfig)
+      else: readConfigFile(changeFileExt(gProjectFull, "nimrod.cfg"))
@@ -1,6 +1,6 @@
 #
 #
-#           The Nimrod Compiler
+#           The Nim Compiler
 #        (c) Copyright 2012 Andreas Rumpf
 #
@@ -14,7 +14,7 @@ import
 
 # ---------------- configuration file parser -----------------------------
-# we use Nimrod's scanner here to safe space and work
+# we use Nim's scanner here to safe space and work
 
 proc ppGetTok(L: var TLexer, tok: var TToken) = 